Alignment Utilities
===================

SE3 Transformations (PyTorch)
-----------------------------

.. automodule:: shepherd_score.alignment.utils.se3
   :members:
   :undoc-members:
   :show-inheritance:

SE3 Transformations (NumPy)
----------------------------

.. automodule:: shepherd_score.alignment.utils.se3_np
   :members:
   :undoc-members:
   :show-inheritance:

SE3 Transformations (JAX)
--------------------------

.. automodule:: shepherd_score.alignment.utils.se3_jax
   :members:
   :undoc-members:
   :show-inheritance:

PCA Utilities (PyTorch)
-----------------------

.. automodule:: shepherd_score.alignment.utils.pca
   :members:
   :undoc-members:
   :show-inheritance:

PCA Utilities (NumPy)
---------------------

.. automodule:: shepherd_score.alignment.utils.pca_np
   :members:
   :undoc-members:
   :show-inheritance:

PCA Utilities (JAX)
-------------------

.. automodule:: shepherd_score.alignment.utils.pca_jax
   :members:
   :undoc-members:
   :show-inheritance:
